@@ -165,16 +165,18 @@ class SynchronizeFiles(Synchronize):
         elif button == 'Configure exchange site':
             exchange_site = self.root().project().get_exchange_site()
             return self.get_result(next_action=exchange_site.configuration.oid())
-        
-        current_site = self.root().project().get_current_site()
-        nb_waiting_init = len(current_site.get_jobs(status="WAITING"))
-        nb_error_init = len(current_site.get_jobs(status='ERROR'))
-        nb_processed_init = len(current_site.get_jobs(status="PROCESSED"))
 
+        # Save initial job counts
+        init_job_count = self._compute_job_count()
+
+        # Process jobs
         super(SynchronizeFiles, self).run(button)
 
-        nb_processed = len(current_site.get_jobs(status="PROCESSED")) - nb_processed_init
-        nb_error = len(current_site.get_jobs(status='ERROR')) - nb_error_init
+        # Print final counts
+        nb_waiting_init = init_job_count['WAITING']
+        nb_processed = self._job_count['PROCESSED'] - init_job_count['PROCESSED']
+        nb_error_init = init_job_count['ERROR']
+        nb_error = self._job_count['ERROR'] - nb_error_init
 
         if nb_processed == nb_waiting_init and nb_error == 0:
             msg = (
@@ -293,9 +295,21 @@ class Synchronization(flow.Object):
     request_revisions = flow.Child(RequestRevisions)
     multi_request_revisions = flow.Child(MultiRequestRevisions)
 
+    def __init__(self, parent, name):
+        super(Synchronization, self).__init__(parent, name)
+        self._initialized = False
+    
+    def _ensure_waiting_count(self):
+        jobs = self._project.get_current_site().queue.job_list
+
+        if not self._initialized:
+            jobs.update_waiting_count()
+            self._initialized = True
+        
+        return jobs.count_waiting.get()
+
     def summary(self):
-        current_site = self._project.get_current_site()
-        nb_waiting_jobs = len(current_site.get_jobs(status="WAITING"))
+        nb_waiting_jobs = self._ensure_waiting_count()
         
         if nb_waiting_jobs > 0:
             return (
