@@ -13,6 +13,7 @@ from .kitsu import KitsuSequence, KitsuShot, UpdateItemsKitsuSettings
 from .site import RequestRevisions, MultiRequestRevisions, MultiRequestedRevisions, SiteJobsPoolNames, ActiveSiteChoiceValue, ActiveSitesMultichoiceValue, RequestedRevisions
 from .dependency import get_dependencies
 from .file import GenericRunAction
+from .users import ToggleBookmarkAction
 
 
 class Casting(flow.Map):
@@ -951,10 +952,10 @@ class RenderSequencePlayblasts(ProcessSequenceFiles):
         oid = f'{self._sequence.oid()}/shots/{shot_name}/departments/{dept_name}/files/{file_name}'
         file = self.root().get_object(oid)
         
-        file.submit_aftereffects_playblast_job.revision_name.set(revision_name)
-        file.submit_aftereffects_playblast_job.priority.set(priority)
-        file.submit_aftereffects_playblast_job.pool.set(pool_name)
-        file.submit_aftereffects_playblast_job.run('Submit job')
+        file.submit_ae_playblast.revision.set(revision_name)
+        # file.submit_ae_playblast.priority.set(priority)
+        file.submit_ae_playblast.pool.set(pool_name)
+        file.submit_ae_playblast.run('Submit')
     
     def _compute_files_data(self):
         # Keep only tasks which contain Blender files
@@ -1127,6 +1128,7 @@ class Sequence(KitsuSequence):
 
     settings = flow.Child(ContextualView).ui(hidden=True)
     description = flow.Param("")
+    toggle_bookmark = flow.Child(ToggleBookmarkAction)
     shots = flow.Child(Shots).ui(expanded=True)
     
     request = flow.Child(RequestSequence).ui(hidden=True)
