@@ -240,7 +240,7 @@ class KitsuBindings(flow.Object):
 
     asset_types = flow.HashParam()
     asset_families = flow.HashParam()
-    task_types_by_file_names = flow.DictParam({})
+    task_type_files = flow.DictParam({})
 
     def _kitsu_api(self):
         return self.root().project().kitsu_api()
@@ -307,12 +307,17 @@ class KitsuBindings(flow.Object):
         
         return self._kitsu_api().get_task(entity, task_type_name)
     
-    def get_task_type(self, file_name):
-        for pattern, type_name in self.task_types_by_file_names.get().items():
+    def get_task_types(self, file_name):
+        task_types = []
+
+        for pattern, type_names in self.task_type_files.get().items():
+            if not isinstance(type_names, list):
+                type_names = [type_names]
+            
             if fnmatch.fnmatch(pattern, file_name):
-                return type_name
+                task_types += type_names
         
-        return None
+        return task_types
     
     def get_entity_data(self, contextual_settings):
         kitsu_api = self.root().project().kitsu_api()
