@@ -77,6 +77,8 @@ class Job(flow.Object):
 
 class JobQueue(flow.Map):
 
+    count_waiting = flow.IntParam(0)
+
     @classmethod
     def mapped_type(cls):
         return Job
@@ -107,6 +109,18 @@ class JobQueue(flow.Map):
 
         return job
     
+    def update_waiting_count(self, count=None):
+        if count is None:
+            count = len(self.jobs(status='WAITING'))
+        
+        self.count_waiting.set(count)
+    
+    def incr_waiting_count(self, by=1):
+        self.count_waiting.incr(by)
+
+    def decr_waiting_count(self, by=1):
+        self.count_waiting.decr(by)
+    
     def submit_job(self,
             emitter_oid,
             user,
@@ -136,6 +150,8 @@ class JobQueue(flow.Map):
         job.is_archived.set(False)
         job.log.set('?')
 
+        self.incr_waiting_count()
+
         self.root().session().log_info("Submitted job %s" % job)
 
         self.touch()
@@ -166,6 +182,10 @@ class JobQueue(flow.Map):
 
 class ProcessJobs(flow.Action):
 
+    def __init__(self, parent, name):
+        super(ProcessJobs, self).__init__(parent, name)
+        self._job_count = {}
+
     def needs_dialog(self):
         return False
 
@@ -178,10 +198,29 @@ class ProcessJobs(flow.Action):
         current_site = self.root().project().get_current_site()
         return current_site.get_jobs()
     
+    def _compute_job_count(self):
+        count = dict.fromkeys(JobStatus.CHOICES, 0)
+
+        for j in self.root().project().get_current_site().get_jobs():
+            count[j.status.get()] += 1
+        
+        return count
+    
     def run(self, button):
+        self._job_count = self._compute_job_count()
+
         for job in self._get_jobs():
             self.root().session().log_info("Processing job %s" % job)
+            
+            self._job_count[job.status.get()] -= 1
             self._process(job)
+            self._job_count[job.status.get()] += 1
+        
+        current_site = self.root().project().get_current_site()
+        current_site.queue.job_list.update_waiting_count(self._job_count['WAITING'])
+
+        # Refresh project's sync section UI
+        self.root().project().synchronization.touch()
 
 
 class MinioFileUploader(PythonRunner):
@@ -387,9 +426,9 @@ class Synchronize(ProcessJobs):
             job.status.set('ERROR')
         else:
             job.status.set("PROCESSED")
-        
-        # Refresh project's sync section UI
-        self.root().project().synchronization.touch()
+        finally:
+            # Decrement number of waiting jobs
+            self.root().project().get_current_site().queue.job_list.decr_waiting_count()
 
 
 class ActiveSiteChoiceValue(flow.values.SessionValue):
